====
TODO
====

* Increase test coverage.
* Finish documentation of :mod:`~pydl.photoop.window`.
* :mod:`pydl.pydlutils.mangle` needs more work.

  - Area (solid angle) calculation.
  - Area calculation needs to account for the
    ``use_caps`` attribute.
  - Intersection of caps with other caps.

* Check ``groupdim``, ``groupsize`` in :func:`~pydl.pydlutils.math.djs_reject`.
  Make sure integer division works.
* Document :class:`~pydl.pydlutils.bspline.bspline`, and incorporate changes
  suggested by the pypit team.
